@@ -12,7 +12,7 @@ from termremind.conf import config
 
 
 def getver():
-    return "0.0.3.1"
+    return "0.0.3.2"
 
 
 VER = getver()
@@ -49,12 +49,16 @@ def exitusage():
 - remind help : Shows this page, and exits
 - remind version : Prints version, and exits
 - remind set <name> <detail> : Sets a reminder with specified details
+- remind edit <name> <new_text> : Changes reminder text
 - remind delete <name> : Removes a reminder with specified name
 - remind reset : Removes all reminders (after confirmation)
 - remind install : Automatically attempts to add itself to your shell startup file
                    (.bashrc or .zshrc depending on detected shell)
 - remind config : Opens the config file in the program specified by $EDITOR
 
+%REP%Formatting%RES%:
+If you wrap text like "%bheeho%r", it will render the text "heeho" as bright text.
+
 %REP%Notes%RES%:
 - Remind's config is located at ~/.config/remind
 - Reminders themselves are just plaintext files stored in ~/.reminds/
@@ -136,6 +140,14 @@ def main():
                 print("Not yet")
             else:
                 os.system("$EDITOR " + os.path.expanduser("~") + CONF_PATH)
+        elif action == "edit":
+            if len(sys.argv) > 3:
+                mgr.delreminder(sys.argv[2])
+                mgr.setermreminder(sys.argv[2], sys.argv[3])
+                print("Edited your reminder.")
+            else:
+                print("Not enough info.")
+                print("Usage: remind edit <name> <new_text>")
         else:
             print("No such option: " + action)
             exitusage()
@@ -151,6 +163,8 @@ def main():
                     + RESET
                     + " : "
                     + mgr.getermreminder(rname)
+                    .replace("%b", colorama.Style.BRIGHT)
+                    .replace("%r", RESET)
                 )
         else:
             for rname in mgr.listermreminders():
